@@ -1,6 +1,6 @@
 from pathlib import Path
 from unittest import mock
-import responses # type: ignore
+import responses  # type: ignore
 import json
 import gzip
 from tests.cli_test_case import CliTestCase
@@ -25,6 +25,20 @@ class MavenTest(CliTestCase):
 
         self.assert_json_orderless_equal(expected, payload)
 
+    @responses.activate
+    def test_subset_by_absolute_time(self):
+        result = self.cli('subset', '--time', '1h30m', '--session',
+                          self.session, 'maven', str(self.test_files_dir.joinpath('java/test/src/java/').resolve()))
+        self.assertEqual(result.exit_code, 0)
+
+        payload = json.loads(gzip.decompress(
+            responses.calls[0].request.body).decode())
+
+        expected = self.load_json_from_file(
+            self.test_files_dir.joinpath('subset_by_absolute_time_result.json'))
+
+        self.assert_json_orderless_equal(expected, payload)
+
     @ responses.activate
     def test_record_test_maven(self):
         result = self.cli('record', 'tests',  '--session', self.session,
